#
# spec file for package xfce4-time-out-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.16.0
%define plugin time-out
%define old_plugname timeout
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.1.4
Release:        1.2
Summary:        Time-out Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-time-out-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.1/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.16.0
BuildRequires:  pkgconfig(x11) >= 1.6.7
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{old_plugname} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{old_plugname} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{old_plugname}-debuginfo

%description
The Time-out plugin allows to take breaks from computer work in configurable,
periodical intervals and will provide a notification and lock the screen each
the break time has been reached.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{old_plugname}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{old_plugname}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libtime-out.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/xfce4/panel/plugins/libtime-out.so
%{_datadir}/icons/hicolor/*/apps/xfce4-time-out-plugin.*
%{_datadir}/xfce4/panel/plugins/xfce4-time-out-plugin.desktop

%files lang -f %{name}.lang

%changelog
* Mon Jan  6 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.4
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * I18n: Update po/LINGUAS list
  * build: Make libx11 optional and add runtime check
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Get rid of intltool
  * Translation Updates
* Fri Apr 21 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.3
  * Fix previous commit
  * Update copyright year
  * Remove deprecated project files
  * build: Add GLib requirement
  * build: Fix autotools warnings
  * Fix blurry image when UI scale > 1
  * build: Fix intltool lock file problem during make distcheck
  * Translation Updates
- Remove _service file
* Mon Mar  1 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.1.2
  * Check whether the seat exists before ungrabbing it
  * Fix compilation warnings
  * autoconf: Some updates
  * fix for no dialog after screenlock issue
    (gxo#panel-plugins/xfce4-time-out-plugin#13)
  * Remove GSourceFunc casts
    (gxo#panel-plugins/xfce4-time-out-plugin!2)
  * Translation Updates
* Thu Jul  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.1.1
  * Do not enable countdown when configuration changes (bxo#16118)
  * Add lock button to break dialog (bxo#16317)
  * Update URLs from goodies.x.o to docs.x.o (bxo#16179)
  * Translation Updates
* Mon Nov  4 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.1.0
  * GTK3 Port
  * React to panel "mode," not "orientation" (bxo#15840)
  * Make time out plugin respect panel icon size (bxo#15839)
  * Allow compilation with panel 4.15
  * Make build less verbose
  * Translation Updates
* Tue Aug 20 2019 Dominique Leuenberger <dleuenberger@suse.com>
- Fix provides/obsoletes: in the past, this plugin was called
  xfce4-panel-plugin-timeout (not -time-out).
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Wed Aug 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.0.3
  - make strings translatable (bxo#8716)
  - Left-align labels for time settings (bxo#6346)
  - Add option to hide icon - fixes bxo#12084
* Mon Jul 29 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Use %%license for COPYING
- Don't add Changelog. NEWS is enough
- Added bcond for git master builds
* Tue Mar 10 2015 gber@opensuse.org
- update to version 1.0.2
  - ditch _xfce_create_framebox() and use xfce_gtk_frame_box_new()
    instead
  - fix transparency (bxo#8747), set the Gtk.EventBox invisible
    like other panel plugins do
  - updated translations
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr 17 2012 gber@opensuse.org
- update to version 1.0.1
  - port to libxfce4ui
  - build the plugin as a module
  - fix double-free when seconds are not displayed
  - port to GtkTooltip
  - emit the 'update' signal only if the countdown is running
  - only call gtk_progress_set_percentage() with valid value
- dropped obsolete
  xfce4-panel-plugin-timeout-1.0.0-hidden_progress_bar.patch
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Fri May 27 2011 gber@opensuse.org
- renamed xfce4-time-out-plugin-1.0.0-hidden_progress_bar.patch to
  xfce4-panel-plugin-timeout-1.0.0-hidden_progress_bar.patch
* Wed May 25 2011 pcerny@novell.com
- fixed invalid progress bar update
  xfce4-time-out-plugin-1.0.0-hidden_progress_bar.patch
  https://bugzilla.xfce.org/show_bug.cgi?id=7660
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
